@@ -41,6 +41,9 @@ Remarks:
         https://github.com/ipython/ipython/issues/10627
 
     This issue might be fixed in matplotlib 3.0.
+
+This script corresponds with GCPy 1.0.2. Edit this version ID if releasing
+a new version of GCPy.
 """
 
 # =====================================================================
@@ -48,7 +51,8 @@ Remarks:
 # ====================================q=================================
 
 import os
-from os.path import join
+from os.path import join, exists
+from shutil import copyfile
 import warnings
 import calendar
 import numpy as np
@@ -179,7 +183,13 @@ if gcpy_test:
     gchp_vs_gchp_resultsdir  = join(mainresultsdir,'GCHP_version_comparison')
     gchp_vs_gcc_resultsdir   = join(mainresultsdir,'GCHP_GCC_comparison')
     diff_of_diffs_resultsdir = join(mainresultsdir,'GCHP_GCC_diff_of_diffs')
-    if not os.path.exists(mainresultsdir): os.mkdir(mainresultsdir)
+    if not exists(mainresultsdir): os.mkdir(mainresultsdir)
+    # Make copy of benchmark script in results directory
+    curfile = os.path.realpath(__file__)
+    dest = join(mainresultsdir,curfile.split('/')[-1])
+    if not exists(dest):
+        copyfile(curfile, dest)
+
 else:
     gcc_vs_gcc_resultsdir    = join(maindir, gcc_dev_dir, results_dir)
     gchp_vs_gchp_resultsdir  = join(maindir, gchp_dev_dir,
@@ -196,7 +206,13 @@ else:
                                      [gcc_vs_gcc,
                                       gchp_vs_gcc or gchp_vs_gchp or gchp_vs_gcc_diff_of_diffs,
                                       gchp_vs_gchp, gchp_vs_gcc, gchp_vs_gcc_diff_of_diffs]):
-        if plotting_type and not os.path.exists(resdir): os.mkdir(resdir)
+        if plotting_type and not exists(resdir): os.mkdir(resdir)
+        if resdir == gcc_vs_gcc_resultsdir or resdir == base_gchp_resultsdir:
+            # Make copy of benchmark script in results directory
+            curfile = os.path.realpath(__file__)
+            dest = join(resdir,curfile.split('/')[-1])
+            if not exists(dest):
+                copyfile(curfile, dest)
 
 gcc_vs_gcc_tablesdir    = join(gcc_vs_gcc_resultsdir, "Tables")
 gchp_vs_gchp_tablesdir  = join(gchp_vs_gchp_resultsdir, "Tables")
@@ -261,9 +277,9 @@ gchp_end_dev_date  = np.datetime64("{}-{}-01T00:00:00".format(gchp_dev_s_stop[0]
 
 # Seconds per month
 gcc_ref_sec_in_bmk_month  = (gcc_end_ref_date  - gcc_ref_date).astype("float64")
-gchp_ref_sec_in_bmk_month = (gchp_end_ref_date - gchp_ref_date).astype("float64")
+gchp_ref_sec_in_bmk_month = (gchp_end_ref_date - gchp_ref_date).astype("float64") * 2
 gcc_dev_sec_in_bmk_month  = (gcc_end_dev_date  - gcc_dev_date).astype("float64")
-gchp_dev_sec_in_bmk_month = (gchp_end_dev_date - gchp_dev_date).astype("float64")
+gchp_dev_sec_in_bmk_month = (gchp_end_dev_date - gchp_dev_date).astype("float64") * 2
 
 # ======================================================================
 # Significant difference filenames
