@@ -41,6 +41,9 @@ Remarks:
         https://github.com/ipython/ipython/issues/10627
 
     This issue might be fixed in matplotlib 3.0.
+
+This script corresponds with GCPy 1.0.2. Edit this version ID if releasing
+a new version of GCPy.
 """
 
 # =====================================================================
@@ -48,7 +51,8 @@ Remarks:
 # =====================================================================
 
 import os
-from os.path import join
+from os.path import join, exists
+from shutil import copyfile
 import warnings
 
 from calendar import monthrange
@@ -182,7 +186,13 @@ if gcpy_test:
     gcc_vs_gcc_resultsdir    = join(mainresultsdir,'GCC_version_comparison')
     gchp_vs_gchp_resultsdir  = join(mainresultsdir,'GCHP_version_comparison')
     gchp_vs_gcc_resultsdir   = join(mainresultsdir,'GCHP_GCC_comparison')
-    if not os.path.exists(mainresultsdir): os.mkdir(mainresultsdir)
+    if not exists(mainresultsdir): os.mkdir(mainresultsdir)
+    # Make copy of benchmark script in results directory
+    curfile = os.path.realpath(__file__)
+    dest = join(mainresultsdir,curfile.split('/')[-1])
+    if not exists(dest):
+        copyfile(curfile, dest)
+
 else:
     gcc_vs_gcc_resultsdir    = join(maindir, gcc_dev_version, results_dir)
     gchp_vs_gchp_resultsdir  = join(maindir, gchp_dev_version,
@@ -195,7 +205,13 @@ else:
                                       gchp_vs_gchp_resultsdir, gchp_vs_gcc_resultsdir],
                                      [gcc_vs_gcc, gchp_vs_gcc or gchp_vs_gchp,
                                       gchp_vs_gchp, gchp_vs_gcc]):
-        if plotting_type and not os.path.exists(resdir): os.mkdir(resdir)
+        if plotting_type and not exists(resdir): os.mkdir(resdir)
+        if resdir == gcc_vs_gcc_resultsdir or resdir == base_gchp_resultsdir:
+            # Make copy of benchmark script in results directory
+            curfile = os.path.realpath(__file__)
+            dest = join(resdir,curfile.split('/')[-1])
+            if not exists(dest):
+                copyfile(curfile, dest)
 
 # Tables directories
 gcc_vs_gcc_tablesdir   = join(gcc_vs_gcc_resultsdir,"Tables")
@@ -733,9 +749,9 @@ if gchp_vs_gcc:
             # Create plots
             bmk.make_benchmark_emis_plots(
                 ref,
-                gcc_vs_gcc_refstr,
+                gchp_vs_gcc_refstr,
                 dev,
-                gcc_vs_gcc_devstr,
+                gchp_vs_gcc_devstr,
                 dst=gchp_vs_gcc_resultsdir,
                 subdst=datestr,
                 weightsdir=weightsdir,
