@@ -1,4 +1,5 @@
 import argparse
+import os
 import numpy as np
 import xarray as xr
 try:
@@ -17,11 +18,10 @@ from gcpy.regrid import make_regridder_S2S, reformat_dims, make_regridder_L2S, \
     make_regridder_C2L, make_regridder_L2L
 from gcpy.util import reshape_MAPL_CS
 
-
 def file_regrid(
         fin, fout, dim_format_in, dim_format_out, cs_res_out=0,
         ll_res_out='0x0', sg_params_in=[1.0, 170.0, -90.0],
-        sg_params_out=[1.0, 170.0, -90.0]):
+        sg_params_out=[1.0, 170.0, -90.0], vert_params_out=[[], []]):
     """
     Regrids an input file to a new horizontal grid specification and saves it
     as a new file.
@@ -59,6 +59,10 @@ def file_regrid(
             [stretch-factor, target longitude, target latitude].
             Not used if dim_format_out is classic
             Default value: [1.0, 170.0, -90.0] (No stretching)
+        vert_params_out: list(list, list) of list-like types
+            Hybrid grid parameter A in hPa and B (unitless) in [AP, BP] format.
+            Needed for lat/lon output if not using full 72-level or 47-level grid
+            Default value: [[], []]
 
     """
 
@@ -89,6 +93,8 @@ def file_regrid(
 
     # save type of data for later restoration
     original_dtype = np.dtype(ds_in[list(ds_in.data_vars)[0]])
+
+    oface_files=[]
     if cs_res_in == cs_res_out and all(
             [v1 == v2 for v1, v2 in zip(sg_params_in, sg_params_out)]):
         print('Skipping regridding since grid parameters are identical')
@@ -106,6 +112,8 @@ def file_regrid(
             sf_out=sg_params_out[0],
             tlon_out=sg_params_out[1],
             tlat_out=sg_params_out[2])
+        # Save temporary output face files to minimize RAM usage
+        oface_files = [os.path.join('.',fout+str(x)) for x in range(6)]
         # For each output face, sum regridded input faces
         oface_datasets = []
         for oface in range(6):
@@ -119,9 +127,12 @@ def file_regrid(
                 oface_regridded,
                 dim='intersecting_ifaces').sum(
                 'intersecting_ifaces',
-                keep_attrs=True)
-            oface_datasets.append(oface_regridded)
-        ds_out = xr.concat(oface_datasets, dim='F')
+                keep_attrs=True).expand_dims({'F':[oface]})
+            oface_regridded.to_netcdf(
+                oface_files[oface],
+                format='NETCDF4_CLASSIC'
+            )
+        ds_out=xr.open_mfdataset(oface_files, combine='by_coords', concat_dim='F')
         # Put regridded dataset back into a familiar format
         ds_out = ds_out.rename({
             'y': 'Y',
@@ -187,7 +198,7 @@ def file_regrid(
             'Z': 'lev'})
         ds_out = drop_and_rename_classic_vars(ds_out, towards_gchp=False)
         ds_out = ds_out.reindex(lev=ds_out.lev[::-1])
-        _, lev_coords, _ = get_vert_grid(ds_out)
+        _, lev_coords, _ = get_vert_grid(ds_out, *vert_params_out)
         ds_out = ds_out.assign_coords({'lev': lev_coords})
         ds_out['lat'].attrs = {'long_name': 'Latitude',
                                'units': 'degrees_north',
@@ -256,6 +267,8 @@ def file_regrid(
     )
     # Print the resulting dataset
     print(ds_out)
+    # Remove any temporary files
+    for f in oface_files: os.remove(f)
 
 
 def rename_restart_variables(ds, towards_gchp=True):
@@ -396,6 +409,13 @@ if __name__ == '__main__':
             'classic'],
         required=True,
         help='format of the output file\'s dimensions (choose from: checkpoint, diagnostic)')
+    parser.add_argument(
+        '--vert_params_out',
+        metavar='VERT',
+        type=list,
+        required=False,
+        help='Hybrid grid parameter A in hPa and B (unitless) in [AP, BP] format')
+
     args = parser.parse_args()
     file_regrid(
         args.filein,
@@ -405,4 +425,5 @@ if __name__ == '__main__':
         args.cs_res_out,
         args.ll_res_out,
         args.sg_params_in,
-        args.sg_params_out)
+        args.sg_params_out,
+        args.vert_params_out)
